#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.3.1
visibility:           public
id:                   stack-2.9.3.1-DjMX9SG7Nt0I5SB0WJpjT4
key:                  stack-2.9.3.1-DjMX9SG7Nt0I5SB0WJpjT4
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  6aae2d5bef9450137542bd9a8dfa0840
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:
    Path.Extended Stack.ComponentFile Stack.PackageFile
    Stack.Types.Cache Stack.Types.Dependency Stack.Types.PackageFile
    Stack.Types.Storage System.Uname

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.3.1-DjMX9SG7Nt0I5SB0WJpjT4
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-JRwGfw4G4faAdkvjZDffZf
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.1-3WEwGthe7is1LBGeoKnQZb array-0.5.6.0
    async-2.2.6-JCsfEU6uxaM3jchWvvttZs
    attoparsec-0.14.4-Lt8CzeQB1UCKNIPCgGeJTD base-4.18.2.1
    base64-bytestring-1.2.1.0-ErbO7EG1OVTInceY2TwMCE
    bytestring-0.11.5.3 casa-client-0.0.4-5fWMfU44KvyDY9V4yf0nEL
    casa-types-0.0.3-EnegUiIpAX19mTtCxifUL4
    colour-2.3.7-29W5OqHU5xg2Mb8GWPJ1eP
    conduit-1.3.6.1-5N1D7XReUYC7Q0FFK7LvDS
    conduit-extra-1.3.8-4QLRWNABAYIHYZwgT1lJOW containers-0.6.7
    crypton-1.0.4-7gnihw9HF3NI2W205N4X1Z
    crypton-conduit-0.2.3-LDSpsxsGOeb1ObeHcScmEq deepseq-1.4.8.1
    directory-1.3.8.5 echo-0.1.4-BCPf0iNIcqQJp7PonIPBEA
    exceptions-0.10.7 extra-1.7.16-8D2X0x8oD0MLkMWmsVnRML
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filelock-0.1.1.9-AQsEg2HkzM2J2kr0Gb9jG4 filepath-1.4.300.1
    fsnotify-0.4.4.0-90y5uFTQYPJ4ST3vqizKOk
    generic-deriving-1.14.7-IHUaGqqw512L4SmnqdNw4t
    hackage-security-0.6.3.2-3iBalP5XR5o3YAwIvOY5Yh
    hashable-1.4.7.0-KEzkDU36XICA02zRvxfUEu
    hi-file-parser-0.1.8.0-I8SSBfGlpMF43Nr6r8nBNB
    hpack-0.38.0-32Y72Klnlpg4AMUHCqIQ9d hpc-0.6.2.0
    http-client-0.7.19-34xXemB7zi7LDrAIS2UIas
    http-client-tls-0.3.6.4-ADnxKMmkuxZIenWWL3GTLT
    http-conduit-2.3.9.1-1YnFk244Wc91jkGBAdKo7A
    http-download-0.2.1.0-n1R3Fl7S6xCOxn0Bgdcoi
    http-types-0.12.4-EqZKGcmXGQgIrxcsE0a1PI
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    mintty-0.1.4-CFeOovjDLzzJb68ZeM2nF
    mono-traversable-1.0.21.0-9Gn7BM4CBxu5Wmd00Xy1JY mtl-2.3.1
    mustache-2.4.3.1-6kmQQHNWUDF1rBln7d9Qu2
    neat-interpolation-0.5.1.4-K4NIr6z0Dig1TWbSCXF4Vi
    network-uri-2.6.4.2-GeBMcWFtBsy42rTUiQRkD3
    open-browser-0.2.1.1-LxNiN4VEneo8bxQiPfYDai
    optparse-applicative-0.18.1.0-1bx6NtkYgnV6peHQkP2ZMq
    pantry-0.8.3-92ESumvmqrn1RxxPERdTeJ
    path-0.9.6-8SXrQuOX4cO28AjkQwb0Jq
    path-io-1.8.2-I8o8tAy2MBt6SlAUD6Jzoh
    persistent-2.14.6.0-9O6Or4QIlw84QWgPl806Vx
    persistent-sqlite-2.13.2.0-Br1QkHymUpi5CJi7hYvemy pretty-1.1.3.6
    primitive-0.9.1.0-J4tB0B9QUoG4JNvPWMquph process-1.6.19.0
    project-template-0.2.1.0-CKy7ofLQ4bW9PBpW675M1C
    random-1.2.1.3-HWePNsfMjqy9mivdeOZEPQ
    retry-0.9.3.1-4M0VmwPDRbq7sF9pdyI4dG
    rio-0.1.24.0-ILFj8o841Gn2vbpIsgWpML
    rio-prettyprint-0.1.9.0-8FQ01UrwA3i7ScYF2xvmE5
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl stm-2.5.1.0
    streaming-commons-0.2.3.1-GUu9bXIaEAZLtOgV92IQRs
    tar-0.6.0.0-CmmEAEoqQksK9s6YdqDFEu template-haskell-2.20.0.0
    temporary-1.3-9na0atCE3tJ2UKXub35K9W text-2.0.2
    text-metrics-0.3.3-HUyvTH4cT6e403rUaCrtL8
    th-reify-many-0.1.10-Cto2LfM9atDC3pEE71qyOW time-1.12.2
    tls-2.0.6-4HTnXxmtVUp7MYpMwmS3as transformers-0.6.1.0
    typed-process-0.2.13.0-J9Ok4xKz1UuGZMKGl1m6ET
    unicode-transforms-0.4.0.1-LtLMdk141LDEDoaqJlDav2 unix-2.8.4.0
    unix-compat-0.7.4.1-4KMmZ8RUI6D4jdDWnXDUAz
    unliftio-0.2.25.1-wbCzY6GGN1Jjb0ZnqHZMi
    unordered-containers-0.2.21-8pZ5d13ZaJk3LfHcqeQHmo
    vector-0.13.2.0-Bce9rIW4lAD9r12sFleKX
    yaml-0.11.11.2-4zqKB1jPXZ171o7QPBTaus
    zip-archive-0.4.3.2-ETDSWh4o3pwBVKmQgtfBqq
    zlib-0.7.1.0-AtmZptwK0384OyXufN2Drn

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

